.. AUTO-GENERATED FILE -- DO NOT EDIT!

models
======

Module: :mod:`models`
---------------------
.. automodule:: ISLP.models

.. currentmodule:: ISLP.models

.. autofunction:: ISLP.models.summarize

